@@ -22,7 +22,6 @@
 #include <libosso-abook/osso-abook.h>
 
 #include "ecs-match.h"
-#include "ecs-window.h"
 
 typedef struct {
   OssoABookMenuExtension parent_instance;
@@ -77,16 +76,6 @@ struct _GtkTreeModelFilterPrivate
   guint reordered_id;
 };
 
-static void
-extended_search_cb (GtkWidget *widget,
-    OssoABookMenuExtension *self)
-{
-  GtkWidget *window;
-
-  window = ecs_window_new ();
-  gtk_widget_show (window);
-}
-
 static gboolean
 visible_func (GtkTreeModel *model,
     GtkTreeIter *iter,
@@ -180,7 +169,6 @@ extended_contacts_search_init (ExtendedContactsSearch *self)
 }
 
 static OssoABookMenuEntry entries[] = {
-  { "Extended Search", 0, 0, G_CALLBACK (extended_search_cb), NULL },
 };
 
 static const OssoABookMenuEntry *
